@@ -29,7 +29,7 @@
 #include "avcodec.h"
 #include "get_bits.h"
 
-typedef struct {
+typedef struct Node {
     int16_t  sym;
     int16_t  n0;
     uint32_t count;
@@ -42,4 +42,6 @@ typedef int (*HuffCmp)(const void *va, const void *vb);
 int ff_huff_build_tree(AVCodecContext *avctx, VLC *vlc, int nb_codes,
                        Node *nodes, HuffCmp cmp, int flags);
 
+void ff_huff_gen_len_table(uint8_t *dst, const uint64_t *stats);
+
 #endif /* AVCODEC_HUFFMAN_H */
